' impl_check_firefox.vbs, ABr, 19-APR-13
' Checks Firefox on a Windows box and pulls down from common location / silent install.

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Required parameters
p_sNetFirefoxLocation = "\\172.24.0.33\AnonRead\Firefox"

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Globals
g_sFirefoxRegWow6432 = "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\Mozilla\Mozilla Firefox"
g_sFirefoxRegDirect = "HKEY_LOCAL_MACHINE\SOFTWARE\Mozilla\Mozilla Firefox"
g_sRefFirefoxVerFile = "winver.txt"
g_sRefKeyVersion = "RefVer"
g_sRefKey32bit = "32bit"
g_sRefKey64bit = "64bit"

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Functions specific to this module

' detect the Firefox path in Windows Registry
Function getFirefoxRegPath()
  Dim str, sQuery, idx

  ' 6432 check first
  sQuery = g_sFirefoxRegWow6432 & "\CurrentVersion"
  str = readFromRegistry(sQuery, g_sNotFound)
  If str = g_sNotFound Then
    ' direct check
    sQuery = g_sFirefoxRegDirect & "\CurrentVersion"
    str = readFromRegistry(sQuery, g_sNotFound)
    If str = g_sNotFound Then
      ' not found, get out
      getFirefoxRegPath = g_sNotFound
    Else
      getFirefoxRegPath = g_sFirefoxRegDirect
    End If
  Else
    getFirefoxRegPath = g_sFirefoxRegWow6432
  End If
End Function

' is Firefox installed?
Function isFirefoxInstalled()
  Dim str
  str = getFirefoxRegPath()
  If str = g_sNotFound Then
    isFirefoxInstalled = False
  Else
    isFirefoxInstalled = True
  End If
End Function

' what is Firefox version?
Function getFirefoxVersion()
  Dim sRegPath, sCurrentVersion, sActualVersion

  ' registry path
  sRegPath = getFirefoxRegPath()

  ' current Firefox version...family only
  sCurrentVersion = readFromRegistry(sRegPath & "\CurrentVersion", g_sNotFound)

  ' format is "20.0.1 (en-US)", so get rid of spaces
  sActualVersion = sCurrentVersion
  idx = Instr(sActualVersion, " ")
  If idx > 0 Then sActualVersion = Left(sActualVersion, idx - 1)
  getFirefoxVersion = sActualVersion
End Function

' is this a 32-bit Firefox?
Function isFirefox32()
  Dim sRegPath, sCurrentVersion, sFirefoxFamily, sActualVersion

  ' registry path
  sRegPath = getFirefoxRegPath()

  ' check for cross install (32-bit on 64-bit system)
  If sRegPath = g_sFirefoxRegWow6432 Then
    ' yup, 32-bit Firefox installed on 64-bit system. this is expected.
    isFirefox32 = True
    Exit Function
  End If

  ' it's a straight install, so check the OS type
  isFirefox32 = isOs32()
End Function

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' BEGIN MAIN PROGRAM

' preamble
writeOutput("check_firefox.vbs: BEGIN")
If Not isFirefoxInstalled() Then doExit("Firefox not detected; nothing to do")

' verify arguments
If WScript.Arguments.Count = 0 Then doExit("ERROR: Must invoke with network path to Firefox install")
p_sNetFirefoxLocation = WScript.Arguments(0)

' get the winver file
p_sNetWinverPath = p_sNetFirefoxLocation & "\" & g_sRefFirefoxVerFile

' check installed version
sFirefoxVersion = getFirefoxVersion()
bFirefoxIs32 = isFirefox32()
If bFirefoxIs32 Then sFirefoxArch = "32-bit" Else sFirefoxArch = "64-bit"
writeOutput("Detected " & sFirefoxArch & " Firefox version '" & sFirefoxVersion & "'")

' check reference version
sRefFirefoxVersion = extractRefKey(p_sNetWinverPath, g_sRefKeyVersion, "")
If isBlank(sRefFirefoxVersion) Then doExit("ERROR: Reference Firefox version is empty; nothing to do")
If sFirefoxVersion = sRefFirefoxVersion Then doExit("Reference Firefox version matches; nothing to do")
writeOutput("Reference Firefox version is '" & sRefFirefoxVersion & "'; need to upgrade")

' get the name of the directory to pull down
If bFirefoxIs32 Then sRefKeyArch = g_sRefKey32bit Else sRefKeyArch = g_sRefKey64bit
sRefFirefoxSrcDir = extractRefKey(p_sNetWinverPath, sRefKeyArch, "")
If isBlank(sRefFirefoxSrcDir) Then doExit("ERROR: Reference Firefox src dir is empty; nothing to do")
writeOutput("Reference Firefox src dir '" & sRefFirefoxSrcDir & "'")

' copy the files
sSrcDir = p_sNetFirefoxLocation & "\" & sRefFirefoxSrcDir
sTempDir = ReadEnv("TEMP")
sDestDir = sTempDir & "\" & sRefFirefoxSrcDir
writeOutput("Clearing intermediate local TEMP folder '" & sRefFirefoxSrcDir & "'")
doCreateFolder sDestDir
doDeleteFolderContents sDestDir
writeOutput("Copying '" & sSrcDir & "' to local TEMP folder")
doCopyFolder sSrcDir, sDestDir
sMsi = getMSI(sDestDir)
writeOutput("Copied and identified Firefox '" & sMsi & "'")

' run the upgrade
'sCmdLine = """" & sDestPath & """ /s /v/qn"" ADDLOCAL=jrecore REBOOT=Suppress JAVAUPDATE=0"""
sSystemRoot = ReadEnv("SystemRoot")
sMsiExec = sSystemRoot & "\system32\msiexec.exe"
sMsiExecLogFile = sDestDir & "\msiexec.log"
' sCmdLine = """" & sMsiExec & " /I " & sMsi & " /qn /norestart ADDLOCAL=All IEXPLORER=1 MOZILLA=1 JAVAUPDATE=0 AU=0 AUTOUPDATECHECK=0 JU=0 REBOOT=Suppress"""
sCmdLine = sMsiExec & " /L*v " & sMsiExec & " /I " & sMsi & " /qn /norestart"
writeOutput("Running: " & sCmdLine)
Set objShell = WScript.CreateObject("WScript.Shell")
objShell.Run sCmdLine, 1, True
Set objShell = Nothing

