' impl_check_jre.vbs, ABr, 19-APR-13
' Checks JRE on a Windows box and pulls down from common location / silent install.

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Required parameters
p_sNetJreLocation = "\\172.24.0.33\AnonRead\JRE"

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Globals
g_sJavaRegWow6432 = "HKEY_LOCAL_MACHINE\SOFTWARE\Wow6432Node\JavaSoft\Java Runtime Environment"
g_sJavaRegDirect = "HKEY_LOCAL_MACHINE\SOFTWARE\JavaSoft\Java Runtime Environment"
g_sRefJreVerFile = "winver.txt"
g_sRefKeyVersion = "RefVer"
g_sRefKey32bit = "32bit"
g_sRefKey64bit = "64bit"

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' Functions specific to this module

' detect the JRE path in Windows Registry
Function getJreRegPath()
  Dim str, sQuery

  ' 6432 check first
  sQuery = g_sJavaRegWow6432 & "\CurrentVersion"
  str = readFromRegistry(sQuery, g_sNotFound)
  If str = g_sNotFound Then
    ' direct check
    sQuery = g_sJavaRegDirect & "\CurrentVersion"
    str = readFromRegistry(sQuery, g_sNotFound)
    If str = g_sNotFound Then
      ' not found, get out
      getJreRegPath = g_sNotFound
    Else
      getJreRegPath = g_sJavaRegDirect
    End If
  Else
    getJreRegPath = g_sJavaRegWow6432
  End If
End Function

' is JRE installed?
Function isJreInstalled()
  Dim str
  str = getJreRegPath()
  If str = g_sNotFound Then
    isJreInstalled = False
  Else
    isJreInstalled = True
  End If
End Function

' what is JRE version?
Function getJreVersion()
  Dim sRegPath, sCurrentVersion, sJavaFamily, sActualVersion

  ' registry path
  sRegPath = getJreRegPath()

  ' current java version...family only
  sCurrentVersion = readFromRegistry(sRegPath & "\CurrentVersion", g_sNotFound)

  ' get family
  sJavaFamily = Right(sCurrentVersion, 1)

  ' read the actual version
  sActualVersion = readFromRegistry(sRegPath & "\Java" & sJavaFamily & "FamilyVersion", g_sNotFound)
  getJreVersion = sActualVersion
End Function

' is this a 32-bit JRE?
Function isJre32()
  Dim sRegPath, sCurrentVersion, sJavaFamily, sActualVersion

  ' registry path
  sRegPath = getJreRegPath()

  ' check for cross install (32-bit on 64-bit system)
  If sRegPath = g_sJavaRegWow6432 Then
    ' yup, 32-bit JRE installed on 64-bit system. this is expected.
    isJre32 = True
    Exit Function
  End If

  ' it's a straight install, so check the OS type
  isJre32 = isOs32()
End Function

'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' BEGIN MAIN PROGRAM

' preamble
writeOutput("check_jre.vbs: BEGIN")
If Not isJreInstalled() Then doExit("JRE not detected; nothing to do")

' verify arguments
If WScript.Arguments.Count = 0 Then doExit("ERROR: Must invoke with network path to JRE install")
p_sNetJreLocation = WScript.Arguments(0)

' get the winver file
p_sNetWinverPath = p_sNetJreLocation & "\" & g_sRefJreVerFile

' check installed version
sJreVersion = getJreVersion()
bJreIs32 = isJre32()
If bJreIs32 Then sJreArch = "32-bit" Else sJreArch = "64-bit"
writeOutput("Detected " & sJreArch & " JRE version '" & sJreVersion & "'")

' check reference version
sRefJreVersion = extractRefKey(p_sNetWinverPath, g_sRefKeyVersion, "")
If isBlank(sRefJreVersion) Then doExit("ERROR: Reference JRE version is empty; nothing to do")
If sJreVersion = sRefJreVersion Then doExit("Reference JRE version matches; nothing to do")
writeOutput("Reference JRE version is '" & sRefJreVersion & "'; need to upgrade")

' get the name of the directory to pull down
If bJreIs32 Then sRefKeyArch = g_sRefKey32bit Else sRefKeyArch = g_sRefKey64bit
sRefJreSrcDir = extractRefKey(p_sNetWinverPath, sRefKeyArch, "")
If isBlank(sRefJreSrcDir) Then doExit("ERROR: Reference JRE src dir is empty; nothing to do")
writeOutput("Reference JRE src dir '" & sRefJreSrcDir & "'")

' copy the files
sSrcDir = p_sNetJreLocation & "\" & sRefJreSrcDir
sTempDir = ReadEnv("TEMP")
sDestDir = sTempDir & "\" & sRefJreSrcDir
writeOutput("Clearing intermediate local TEMP folder '" & sRefJreSrcDir & "'")
doCreateFolder sDestDir
doDeleteFolderContents sDestDir
writeOutput("Copying '" & sSrcDir & "' to local TEMP folder")
doCopyFolder sSrcDir, sDestDir
sMsi = getMSI(sDestDir)
writeOutput("Copied and identified JRE '" & sMsi & "'")

' run the upgrade
'sCmdLine = """" & sDestPath & """ /s /v/qn"" ADDLOCAL=jrecore REBOOT=Suppress JAVAUPDATE=0"""
sSystemRoot = ReadEnv("SystemRoot")
sMsiExec = sSystemRoot & "\system32\msiexec.exe"
' sCmdLine = """" & sMsiExec & " /I " & sMsi & " /qn /norestart ADDLOCAL=All IEXPLORER=1 MOZILLA=1 JAVAUPDATE=0 AU=0 AUTOUPDATECHECK=0 JU=0 REBOOT=Suppress"""
sCmdLine = sMsiExec & " /I " & sMsi & " /qn /norestart ADDLOCAL=All IEXPLORER=1 MOZILLA=1 JAVAUPDATE=0 AU=0 AUTOUPDATECHECK=0 JU=0 REBOOT=Suppress"
writeOutput("Running: " & sCmdLine)
Set objShell = WScript.CreateObject("WScript.Shell")
objShell.Run sCmdLine, 1, True
Set objShell = Nothing

